/** ***************************************************************************
  * @file    lcd_1602.h																												*
  * @author  PLUM, Maciej Szumski																							*
  * @version V1.0																															*
  * @date    12-February-2016																									*
  * @brief   This file contains all the functions prototypes for the LCD1602	*
  *****************************************************************************/
// Definicje instrukcji sterownika HD44780 --------------------
#define LCD_CLEAR					       	0x01
#define LCD_HOME					       	0x02
#define LCD_ENTRY_MODE				   	0x04
#define LCD_EM_SHIFT_CURSOR		 		0
#define LCD_EM_SHIFT_DISPLAY	 		1
#define LCD_EM_DECREMENT		   		0
#define LCD_EM_INCREMENT		   		2
#define LCD_DISPLAY_ONOFF			   	0x08
#define LCD_DISPLAY_OFF		     		0
#define LCD_DISPLAY_ON			   		4
#define LCD_CURSOR_OFF			   		0
#define LCD_CURSOR_ON			     		2
#define LCD_CURSOR_NOBLINK	   		0
#define LCD_CURSOR_BLINK		   		1
#define LCD_DISPLAY_CURSOR_SHIFT 	0x10
#define LCD_SHIFT_CURSOR		   		0
#define LCD_SHIFT_DISPLAY		   		8
#define LCD_SHIFT_LEFT			   		0
#define LCD_SHIFT_RIGHT		     		4
#define LCD_CGRAM_SET				 		 	0x40
#define LCD_DDRAM_SET				 		 	0x80

// opóźnienie programowe: -------------------------------------
// counter 	=      38 <->   5 us (mikrosekund)
//		  		=      78 <->  10 us
//		  		=     784 <-> 100 us
//		  		=  32'800 <->   4.1 ms
//		  		= 120'000 <->  15 ms
//      		=     8e6 <->   1 sekunda
void delay_us(unsigned int);
unsigned char LCD_ReadStatus(void);		// odczytuje BUSY FLAG
void LCD_SendCommand(unsigned char);
void LCD_WriteCharacter(unsigned char);
//LCD_Initialize: ---------------------------------------------
// programowa inicjalizacja wyświetlacza LCD1602
// inicjuje też odpowiednie linie portu GPIOC
void LCD_Initialize(void);

void LCD_WriteText(unsigned char * text);
void LCD_GoTo(unsigned char x, unsigned char y);
void LCD_WriteTextXY(unsigned char * text, unsigned char x, unsigned char y);
void LCD_SetUserChar (unsigned char chrNum, unsigned char n, const unsigned char *p);
void LCD_WriteBin(unsigned int var, int bitCount);
void LCD_WriteHex(unsigned int var);

/**************** (C) COPYRIGHT 2016 PLUMicroelectronics *****END OF FILE******/
