/******************************************************
 *  Systemy Mikroprocesorowe w Sterowaniu,  WEiTI PW 	*
 *  ZL27ARM: PROJEKT_27 czujnik temperatury TC77 - SPI*
 ******************************************************/
// na plycie ZL27ARM nalezy polaczyc
// JP7 (2) TC_CS  <---> PA4 - SPI1_NSS
// JP7 (4) TC_SIO <---> PA7 - SPI1_MOSI
// JP7 (6) TC_SCK <---> PA5 - SPI1_SCK

#include "stm32f10x.h"
#include <stdbool.h> 		// true, false
#include <stdio.h>
#include ".\..\Drivers\LCD1602\lcd_1602.h"
#define SPI_Mode_Slave_Mask ((unsigned short int)0xFEFB)  // maska pozwalajaca wyzerowac bity trybu pracy wprost w rejestrzez SPIx->CR1

int  RCC_Config(void);
void GPIO_Config(void);
void SPI_Config(void);

// zmienne globalne -------------------------------------------
unsigned char txt2LCD[32] = {0}; 	// bufor funkcji sprintf

int main(void) {
	unsigned int T;
	
  //konfiguracja systemu
  RCC_Config();		
  GPIO_Config(); 
	SPI_Config(); 
  GPIO_ResetBits(GPIOB, 0xFF00u);		// zgasimy wszystkie diody LED																									
	LCD_Initialize();                 //inicjalizacja wysietlacza
	while(1){
		SPI1->CR1 |= SPI_Mode_Master;     // ustaw tryb master - wymusi to zmiane stanu NSS na niski
		while (SPI_I2S_GetFlagStatus(SPI1, SPI_I2S_FLAG_RXNE) == RESET); // czekaj na dane
		T = SPI_I2S_ReceiveData(SPI1);  // odczytaj dane
		if ((T&0x04)==0)                // sprawdz, czy zakonczono juz pierwszy pomiar po wlaczeniu ukladu TC77
      T=0;                        	// jesli nie, ustaw temp=0,  wprzeciwnym razie wynik bedzie bledny (>500stC)
	
		T = T >> 3;                     // usun 3 LSB
		SPI1->CR1 &= SPI_Mode_Slave_Mask;  // ustaw tryb slave - wymusi to zmiane stanu NSS na wysoki

		T = (T * 625)/100;                  // 1 bit temperatury odpowiada 0,0625 stopnia
		snprintf((char *)txt2LCD,31,"TC77->T = %2d.%d C ", T / 100, (T % 100)/10 );
		LCD_WriteTextXY(txt2LCD,0,0);  
		delay_us(1000000);
		GPIO_WriteBit(GPIOB, GPIO_Pin_15, (BitAction)(1-GPIO_ReadOutputDataBit(GPIOB, GPIO_Pin_15)));
	}
}
//------------ konfiguracja RCC: sygnaly taktujace ------------
int RCC_Config(void) {
  ErrorStatus HSEStartUpStatus;                          // zmienna opisujaca rezultat uruchomienia HSE

  RCC_DeInit();                                          // RCC na 'default reset state'
  RCC_HSEConfig(RCC_HSE_ON);                             // wlacz HSE
  HSEStartUpStatus = RCC_WaitForHSEStartUp();            // czekaj na gotowosc HSE
  if(HSEStartUpStatus == SUCCESS) {
    FLASH_PrefetchBufferCmd(FLASH_PrefetchBuffer_Enable);//
    FLASH_SetLatency(FLASH_Latency_2);                   // zwloka Flasha: 2 takty dla 72MHz
    RCC_HCLKConfig(RCC_SYSCLK_Div1);                     // HCLK=SYSCLK
    RCC_PCLK2Config(RCC_HCLK_Div1);                      // PCLK2=HCLK
    RCC_PCLK1Config(RCC_HCLK_Div2);                      // PCLK1=HCLK/2
    RCC_PLLConfig(RCC_PLLSource_HSE_Div1, RCC_PLLMul_9); // PLLCLK = HSE*9 czyli 8MHz * 9 = 72 MHz
    RCC_PLLCmd(ENABLE);                                  // wlacz PLL
    while(RCC_GetFlagStatus(RCC_FLAG_PLLRDY) == RESET);  // czekaj na uruchomienie PLL
    RCC_SYSCLKConfig(RCC_SYSCLKSource_PLLCLK);           // ustaw PLL jako zrodlo sygnalu zegarowego
    while(RCC_GetSYSCLKSource() != 0x08);                // czekaj az PLL bedzie sygnalem zegarowym systemu
// konfiguracja sygnalow taktujacych uzywanych peryferii 
		RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOA, ENABLE);// GPIO A ( SPI   ) 
    RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOB, ENABLE);// GPIO B ( LEDy  ) 
		RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOC, ENABLE);// GPIO C (LCD1602)
		RCC_APB2PeriphClockCmd(RCC_APB2Periph_SPI1, ENABLE); //wlacz taktowanie SPI
		return 0;
  }
	else
		return 1;
}
//------------------ konfiguracja portow GPIO -----------------
void GPIO_Config(void) {
  GPIO_InitTypeDef  GPIO_InitStructure; 

  // LED1 ... LED8 na plytce
  GPIO_InitStructure.GPIO_Pin = 0xFF00u; 	// piny 15,14,...9,8
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_2MHz;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;      // wyjscie w trybie push-pull
  GPIO_Init(GPIOB, &GPIO_InitStructure);
	
	// SPI1 : SCK, MISO and MOSI 
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_4 | GPIO_Pin_5 | GPIO_Pin_6 | GPIO_Pin_7;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AF_PP;
  GPIO_Init(GPIOA, &GPIO_InitStructure);
}
void SPI_Config(void)
{
  //konfigurowanie interfejsu SPI
  SPI_InitTypeDef   SPI_InitStructure;

  SPI_InitStructure.SPI_Direction = SPI_Direction_1Line_Rx;         // transmisja z wykorzystaniem jednej linii, transmisja jednokierunkowa
  SPI_InitStructure.SPI_Mode = SPI_Mode_Slave;                      // tryb pracy SPI
  SPI_InitStructure.SPI_DataSize = SPI_DataSize_16b;                // 16-bit ramka danych 
  SPI_InitStructure.SPI_CPOL = SPI_CPOL_Low;                        // stan sygnalu taktujacego przy braku transmisji - niski
  SPI_InitStructure.SPI_CPHA = SPI_CPHA_1Edge;                      // aktywne zbocze sygnalu taktujacego - 1-sze zbocze
  SPI_InitStructure.SPI_NSS = SPI_NSS_Hard;                         // sprzetowa obsluga linii NSS (CS)
  SPI_InitStructure.SPI_BaudRatePrescaler = SPI_BaudRatePrescaler_256;// prescaler szybkosci tansmisji  36MHz/256=140.625kHz
  SPI_InitStructure.SPI_FirstBit = SPI_FirstBit_MSB;                // pierwszy bit w danych najbardziej znaczacy
  SPI_InitStructure.SPI_CRCPolynomial = 7;                          // stopien wielomianu do obliczania sumy CRC
  SPI_Init(SPI1, &SPI_InitStructure);                               // inicjalizacja SPI
  SPI_SSOutputCmd(SPI1, ENABLE);                                    

  SPI_Cmd(SPI1, ENABLE);  	// Wlacz SPI1
}













